@@ -153,6 +153,23 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         if functions is not None:
             self.add_functions(functions=functions)
 
+    ##########################################################################
+    # Meta Info
+    ##########################################################################
+
+    def update_rate_meta_info(self, rate: str, meta_info: dict) -> None:
+        """Update meta info of a rate.
+
+        Parameters
+        ----------
+        rate : str
+            Name of the rate
+        meta_info : dict
+            Meta info of the rate. Allowed keys are
+            {common_name, gibbs0, ec, database_links, notes, sbml_function}
+        """
+        self.update_meta_info(component="rates", meta_info={rate: meta_info})
+
     ##########################################################################
     # Basic rate functions
     ##########################################################################
@@ -315,7 +332,9 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
             self._check_rate_consistency(rate)
 
     def add_rates(
-        self, rates: Dict[str, Any], meta_info: Optional[Dict[str, Any]] = None
+        self,
+        rates: Dict[str, Any],
+        meta_info: Optional[Dict[str, Any]] = None,
     ) -> None:
         """Add multiple rates to the model.
 
@@ -340,6 +359,7 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         dynamic_variables: Optional[List[str]] = None,
         args: Optional[List[str]] = None,
         check_consistency: bool = True,
+        **meta_info: Dict[str, Any],
     ) -> None:
         """Update an existing rate.
 
@@ -429,24 +449,14 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
 
         if check_consistency:
             self._check_rate_consistency(rate)
+        self.update_rate_meta_info(rate_name, meta_info)
 
-    def update_rates(self, rates: dict) -> None:
+    def update_rates(self, rates: dict, meta_info: Optional[Dict[str, Any]] = None,) -> None:
         """Update multiple rates."""
+        meta_info = {} if meta_info is None else meta_info
         for rate_name, rate in rates.items():
-            self.update_rate(rate_name, **rate)
-
-    def update_rate_meta_info(self, rate: str, meta_info: dict) -> None:
-        """Update meta info of a rate.
-
-        Parameters
-        ----------
-        rate : str
-            Name of the rate
-        meta_info : dict
-            Meta info of the rate. Allowed keys are
-            {common_name, gibbs0, ec, database_links, notes, sbml_function}
-        """
-        self.update_meta_info(component="rates", meta_info={rate: meta_info})
+            info = meta_info.get(rate_name, {})
+            self.update_rate(rate_name, **rate, **info)
 
     def remove_rate(self, rate_name: str) -> None:
         """Remove a rate function from the model.
