@@ -16,7 +16,6 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union, ca
 
 import libsbml
 import numpy as np
-import pandas as pd
 
 from ...core import (
     AlgebraicMixin,
@@ -257,12 +256,21 @@ class Model(_AbstractRateModel, BaseModel):
                     }
                 )
 
-    def update_parameter(self, parameter_name: str, parameter_value: float) -> None:
-        super().update_parameter(parameter_name, parameter_value)
+    def update_parameter(
+        self,
+        parameter_name: str,
+        parameter_value: float,
+        **meta_info: Dict[str, Any],
+    ) -> None:
+        super().update_parameter(parameter_name, parameter_value, **meta_info)
         self._update_derived_stoichiometries()
 
-    def update_parameters(self, parameters: Dict[str, float]) -> None:
-        super().update_parameters(parameters)
+    def update_parameters(
+        self,
+        parameters: Dict[str, float],
+        meta_info: Optional[Dict[str, Any]] = None,
+    ) -> None:
+        super().update_parameters(parameters, meta_info)
         self._update_derived_stoichiometries()
 
     def add_reaction(
@@ -338,6 +346,8 @@ class Model(_AbstractRateModel, BaseModel):
         args: List[str],
         reversible: bool | None = None,
         derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
+        check_consistency: bool = True,
+        **meta_info: Dict[str, Any],
     ) -> None:
         self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
@@ -378,6 +388,8 @@ class Model(_AbstractRateModel, BaseModel):
             dynamic_variables=dynamic_variables,
             args=args,
             reversible=reversible,
+            check_consistency=check_consistency,
+            **meta_info,
         )
 
     def update_reaction(
@@ -392,6 +404,7 @@ class Model(_AbstractRateModel, BaseModel):
         reversible: bool | None = None,
         check_consistency: bool = True,
         derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
+        **meta_info: Dict[str, Any],
     ) -> None:
         """Update an existing reaction.
 
@@ -426,6 +439,7 @@ class Model(_AbstractRateModel, BaseModel):
             dynamic_variables=dynamic_variables,
             args=args,
             check_consistency=check_consistency,
+            **meta_info,
         )
 
     def update_reactions(self, reactions: dict) -> None:
@@ -441,6 +455,7 @@ class Model(_AbstractRateModel, BaseModel):
         reversible: bool | None = None,
         check_consistency: bool = True,
         derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
+        **meta_info: Dict[str, Any],
     ) -> None:
         if stoichiometry is not None:
             self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
@@ -493,6 +508,7 @@ class Model(_AbstractRateModel, BaseModel):
             dynamic_variables=dynamic_variables,
             args=args,
             check_consistency=check_consistency,
+            **meta_info,
         )
 
     def add_reaction_from_ratelaw(
