@@ -294,6 +294,7 @@ def get_response_coefficients_array(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Array, Array]:
@@ -304,7 +305,9 @@ def get_response_coefficients_array(
     frcs = np.full(
         shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan
     )
-    for i, parameter in tqdm(enumerate(parameters), total=len(parameters)):
+    for i, parameter in tqdm(
+        enumerate(parameters), total=len(parameters), disable=disable_tqdm
+    ):
         crc, frc = get_response_coefficients(
             model=model,
             parameter=parameter,
@@ -329,6 +332,7 @@ def get_response_coefficients_df(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
@@ -341,6 +345,7 @@ def get_response_coefficients_df(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )
     crcs_df = pd.DataFrame(
@@ -386,6 +391,7 @@ def get_concentration_response_coefficients_array(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     **integrator_kwargs: Dict[str, Any],
 ) -> Array:
@@ -398,6 +404,7 @@ def get_concentration_response_coefficients_array(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )[0]
 
@@ -406,6 +413,7 @@ def get_concentration_response_coefficients_df(
     model: Model,
     parameters: List[str],
     y: Dict[str, float],
+    disable_tqdm: bool = False,
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
@@ -421,6 +429,7 @@ def get_concentration_response_coefficients_df(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )[0]
 
@@ -455,6 +464,7 @@ def get_flux_response_coefficients_array(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     **integrator_kwargs: Dict[str, Any],
 ) -> Array:
@@ -467,6 +477,7 @@ def get_flux_response_coefficients_array(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )[1]
 
@@ -478,6 +489,7 @@ def get_flux_response_coefficients_df(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     **integrator_kwargs: Dict[str, Any],
 ) -> pd.DataFrame:
@@ -490,6 +502,7 @@ def get_flux_response_coefficients_df(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )[1]
 
@@ -502,7 +515,7 @@ def plot_coefficient_heatmap(
     columns: list[str] | None = None,
     vmax: float | None = None,
     vmin: float | None = None,
-    norm: plt.Normalize | None = None,
+    norm: plt.Normalize | None = None,  # type: ignore
     annotate: bool = True,
     colorbar: bool = True,
     xlabel: str | None = None,
@@ -543,6 +556,7 @@ def plot_multiple(
     cmap: str = "RdBu_r",
     annotate: bool = True,
     colorbar: bool = True,
+    neutral_midpoint: bool = True,
     figsize: Tuple[int, int] | None = None,
 ) -> Tuple[Figure, Axes]:
     """Plot multiple heatmaps of the response coefficient DataFrames.
@@ -553,6 +567,10 @@ def plot_multiple(
     """
     vmin = min(i.values.min() for i in dfs)
     vmax = max(i.values.max() for i in dfs)
+    if neutral_midpoint:
+        total = max((abs(vmin), vmax))
+        vmin = -total
+        vmax = total
 
     n_cols = 2
     n_rows = math.ceil(len(dfs) / n_cols)
@@ -581,7 +599,7 @@ def plot_multiple(
             cm.ScalarMappable(norm=norm, cmap=cmap),
             ax=axs.ravel()[-1],
         )
-        cb.outline.set_linewidth(0)
+        cb.outline.set_linewidth(0)  # type: ignore
     fig.tight_layout()
     return fig, axs
 
@@ -593,6 +611,7 @@ def plot_concentration_response_coefficients(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     cmap: str = "RdBu_r",
     rows: list[str] | None = None,
@@ -622,6 +641,7 @@ def plot_concentration_response_coefficients(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )
     return plot_coefficient_heatmap(
@@ -648,6 +668,7 @@ def plot_flux_response_coefficients(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     tolerance: float = _DEFAULT_TOLERANCE,
+    disable_tqdm: bool = False,
     simulation_kwargs: Dict[str, Any] | None = None,
     cmap: str = "RdBu_r",
     rows: list[str] | None = None,
@@ -677,6 +698,7 @@ def plot_flux_response_coefficients(
         displacement=displacement,
         tolerance=tolerance,
         simulation_kwargs=simulation_kwargs,
+        disable_tqdm=disable_tqdm,
         **integrator_kwargs,
     )
     return plot_coefficient_heatmap(
