@@ -12,7 +12,7 @@ __all__ = [
 
 import itertools as it
 import math
-from typing import Any, Dict, Iterable, List, Optional, Sized, Tuple, Union, cast
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union, cast
 
 import matplotlib.pyplot as plt
 import numpy as np
